==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/OwaspCrsExclusionEntrySelectorMatchOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * When matchVariable is a collection, operate on the selector to specify which elements in the collection this exclusion applies to.
 */
public enum class OwaspCrsExclusionEntrySelectorMatchOperator(
    public val javaValue:
    com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator> {
    Equals(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.Equals),
    Contains(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.Contains),
    StartsWith(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.StartsWith),
    EndsWith(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.EndsWith),
    EqualsAny(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.EqualsAny),
    ;

    override fun toJava():
        com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator = javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator):
            OwaspCrsExclusionEntrySelectorMatchOperator =
            OwaspCrsExclusionEntrySelectorMatchOperator.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/OwaspCrsExclusionEntrySelectorMatchOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * When matchVariable is a collection, operate on the selector to specify which elements in the collection this exclusion applies to.
 */
public enum class OwaspCrsExclusionEntrySelectorMatchOperator(
    public val javaValue: com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator> {
    Equals(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.Equals),
    Contains(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.Contains),
    StartsWith(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.StartsWith),
    EndsWith(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.EndsWith),
    EqualsAny(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator.EqualsAny),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntrySelectorMatchOperator): OwaspCrsExclusionEntrySelectorMatchOperator =
            OwaspCrsExclusionEntrySelectorMatchOperator.values().first { it.javaValue == javaType }
    }
}
